@@ -1,7 +1,7 @@
 """
 Type annotations for sagemaker-runtime service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/client.html)
+[Open documentation](./client.md)
 
 Usage::
 
@@ -16,7 +16,7 @@ from typing import IO, Any, Dict, Type, Union
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_sagemaker_runtime.type_defs import InvokeEndpointOutputTypeDef
+from .type_defs import InvokeEndpointOutputTypeDef
 
 __all__ = ("SageMakerRuntimeClient",)
 
@@ -39,8 +39,8 @@ class Exceptions:
 
 class SageMakerRuntimeClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/client.html)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client)
+    [Show boto3-stubs documentation](./client.md)
     """
 
     meta: ClientMeta
@@ -48,8 +48,8 @@ class SageMakerRuntimeClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/client.html#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def generate_presigned_url(
@@ -60,8 +60,8 @@ class SageMakerRuntimeClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/client.html#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def invoke_endpoint(
@@ -77,6 +77,6 @@ class SageMakerRuntimeClient:
         InferenceId: str = None,
     ) -> InvokeEndpointOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.invoke_endpoint)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/client.html#invoke-endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.invoke_endpoint)
+        [Show boto3-stubs documentation](./client.md#invoke_endpoint)
         """
